Index: asterisk/apps/app_authenticate.c
===================================================================
RCS file: /usr/cvsroot/asterisk/apps/app_authenticate.c,v
retrieving revision 1.13
diff -u -r1.13 app_authenticate.c
--- asterisk/apps/app_authenticate.c	23 Aug 2005 15:21:48 -0000	1.13
+++ asterisk/apps/app_authenticate.c	29 Aug 2005 14:00:43 -0000
@@ -38,8 +38,8 @@
 static char *synopsis = "Authenticate a user";
 
 static char *descrip =
-"  Authenticate(password[|options]): Requires a user to enter a"
-"given password in order to continue execution.  If the\n"
+"  Authenticate(password[|options][|maxdigits]): Requires a user\n"
+"to enter a given password in order to continue execution.  If the\n"
 "password begins with the '/' character, it is interpreted as\n"
 "a file which contains a list of valid passwords (1 per line).\n"
 "an optional set of opions may be provided by concatenating any\n"
@@ -52,6 +52,10 @@
 "         account code will be set\n"
 "     j - Support jumping to n+101\n"
 "     r - Remove database key upon successful entry (valid with 'd' only)\n"
+"     maxdigits  - maximum acceptable number of digits. Stops reading after\n"
+"         maxdigits have been entered (without requiring the user to\n"
+"         press the '#' key).\n"
+"         Defaults to 0 - no limit - wait for the user press the '#' key.\n"
 "\n"
 "When using a database key, the value associated with the key can be\n"
 "anything.\n"
@@ -69,10 +73,12 @@
 	int res=0;
 	int jump = 0;
 	int retries;
+	int maxdigits;
 	struct localuser *u;
 	char password[256]="";
 	char passwd[256];
 	char *opts;
+	char *tmp;
 	char *prompt;
 	if (!data || ast_strlen_zero(data)) {
 		ast_log(LOG_WARNING, "Authenticate requires an argument(password)\n");
@@ -95,10 +101,21 @@
 		opts = "";
 	if (strchr(opts, 'j'))
 		jump = 1;
+	tmp = strchr(opts, '|');
+	if (tmp) {
+		*tmp = 0;
+		tmp++;
+		maxdigits = strtol(tmp, NULL, 10);
+		if ((maxdigits<1) || (maxdigits>254))
+                        maxdigits = 254;
+	} else {
+		maxdigits = 254;
+	}
+	ast_log(LOG_DEBUG, "Accepting a maximum of %d digits.\n", maxdigits);
 	/* Start asking for password */
 	prompt = "agent-pass";
 	for (retries = 0; retries < 3; retries++) {
-		res = ast_app_getdata(chan, prompt, passwd, sizeof(passwd) - 2, 0);
+		res = ast_app_getdata(chan, prompt, passwd, maxdigits, 0);
 		if (res < 0)
 			break;
 		res = 0;
